@@ -1,5 +1,14 @@
 var NAVTREEINDEX6 =
 {
+"structCommonQuantParams.html#a357284012595df64bd5d687fa667825e":[13,0,58,7],
+"structCommonQuantParams.html#a4f9755f8ced8ec35d3dc0986c4c3ce3b":[13,0,58,11],
+"structCommonQuantParams.html#a5285812982f35c7324e2a071bde7baad":[13,0,58,15],
+"structCommonQuantParams.html#a5770765a82200e84a9e621f1632b3f5d":[13,0,58,5],
+"structCommonQuantParams.html#a5a12ee629649c8c1958238cd238b36bc":[13,0,58,14],
+"structCommonQuantParams.html#a6825895b20499860191f94b908be2f39":[13,0,58,2],
+"structCommonQuantParams.html#a69949db8cd0b812e3c8485e0585d6da2":[13,0,58,16],
+"structCommonQuantParams.html#a7a9038020ad4b2a837f75c964e9cbd40":[13,0,58,0],
+"structCommonQuantParams.html#a966913d34df3a5909feb612e714bd6b3":[13,0,58,8],
 "structCommonQuantParams.html#aaeafbb83ee5df9c8fbba96f3cd250338":[13,0,58,13],
 "structCommonQuantParams.html#ad5a34dbb0ead83ec6d2ef1a598ed832d":[13,0,58,6],
 "structCommonQuantParams.html#ade3a29210ea7504fcba1c4bcacd1e692":[13,0,58,3],
@@ -77,7 +86,7 @@ var NAVTREEINDEX6 =
 "structExternalFlags.html#ac3e082f752e9ee5aeb610ca0b7640511":[13,0,68,3],
 "structFIRSTPASS__INFO.html":[13,0,72],
 "structFIRSTPASS__INFO.html#a13a682830f15eb5ad80c20541d1ffba5":[13,0,72,5],
-"structFIRSTPASS__INFO.html#a50cf9d3363ae09efb3ba5827beb22eb2":[13,0,72,0],
+"structFIRSTPASS__INFO.html#a62d8134f6323986a4608194f53fe66aa":[13,0,72,0],
 "structFIRSTPASS__INFO.html#a79971ac2f41950e2330721078f55cafd":[13,0,72,7],
 "structFIRSTPASS__INFO.html#a98b02ddacc1149ec363e152881d7fffe":[13,0,72,6],
 "structFIRSTPASS__INFO.html#a9fbac08fbb591865fd4ecbfb44fe7505":[13,0,72,2],
@@ -170,40 +179,37 @@ var NAVTREEINDEX6 =
 "structHIGH__LEVEL__SPEED__FEATURES.html#abbc8b917d795abbee76fa2fc9efe8c85":[13,0,80,4],
 "structHIGH__LEVEL__SPEED__FEATURES.html#ad4e0881065dd85ccb05b27099c3d8386":[13,0,80,9],
 "structHIGH__LEVEL__SPEED__FEATURES.html#ae5ac0472be257e6c45626e00c7eefe6b":[13,0,80,1],
-"structInitialDimensions.html":[13,0,81],
-"structInitialDimensions.html#ae7bb3f40ad679389312c89fe5e917af3":[13,0,81,1],
-"structInitialDimensions.html#af3b072e04b30ea79a207e250de4c9973":[13,0,81,0],
-"structInterModeSearchStateNonrd.html":[13,0,83],
-"structInterModeSearchStateNonrd.html#a0cabdd6a7dfdee2da308b9e271d10bed":[13,0,83,7],
-"structInterModeSearchStateNonrd.html#a0d2e5f58a3f9254b8dc9b19ccc23f702":[13,0,83,6],
-"structInterModeSearchStateNonrd.html#a68ec2e02b4d7315a1ab243eeb2b0f100":[13,0,83,12],
-"structInterModeSearchStateNonrd.html#a7902e93c764b658c9fd23c734e06310a":[13,0,83,3],
-"structInterModeSearchStateNonrd.html#a7bf6b189051fc21d1512cd29f8c5d69f":[13,0,83,1],
-"structInterModeSearchStateNonrd.html#a87957fe5a1584caef2b7818e5da64695":[13,0,83,5],
-"structInterModeSearchStateNonrd.html#a9a6f2e0a44621f6ef8e564f48c7b8cc7":[13,0,83,11],
-"structInterModeSearchStateNonrd.html#aa3dd8ee97c07a4dc050cc3ef29cfd870":[13,0,83,8],
-"structInterModeSearchStateNonrd.html#ab9240c2a2cd6167b0d51e1b3bd2ffa77":[13,0,83,9],
-"structInterModeSearchStateNonrd.html#ac2af8e4822aec07824785cb557f065eb":[13,0,83,2],
-"structInterModeSearchStateNonrd.html#adc34c3bd6e76679bee3e4a4b07733e49":[13,0,83,10],
-"structInterModeSearchStateNonrd.html#adf419a54df62c1845b8319192ce31f3b":[13,0,83,0],
-"structInterModeSearchStateNonrd.html#afe7f91fe92c4dfdade435538380c9431":[13,0,83,4],
-"structInterpSearchFlags.html":[13,0,84],
-"structInterpSearchFlags.html#a1720ff86680c7e8e7b2f77d4a23d5790":[13,0,84,0],
-"structInterpSearchFlags.html#a92fde19334f66058b6eac0efa041cf34":[13,0,84,1],
-"structIntraBCMVCosts.html":[13,0,85],
-"structIntraBCMVCosts.html#a110357a01a87108133fccf1afefa389b":[13,0,85,2],
-"structIntraBCMVCosts.html#a7f8582d04ace4eeee99a3deb3b8771d8":[13,0,85,1],
-"structIntraBCMVCosts.html#ae77e28c15cf4f18cd35ea8406d9b1fd4":[13,0,85,0],
-"structIntraModeCfg.html":[13,0,86],
-"structIntraModeCfg.html#a09f1535b47b58079a6818ed31f636e92":[13,0,86,6],
-"structIntraModeCfg.html#a21efde3a70fba9fd93db0ea8229b15d6":[13,0,86,2],
-"structIntraModeCfg.html#a25e90d1483c243b3f1d68babc5006cc9":[13,0,86,8],
-"structIntraModeCfg.html#a5907afc4c7e63e9f64c2ab56600c3e77":[13,0,86,1],
-"structIntraModeCfg.html#a99fb2a4f0aafc9bd5ac17905e614f83c":[13,0,86,5],
-"structIntraModeCfg.html#aaf15940fb88791de54e8260a9d4b6e0a":[13,0,86,3],
-"structIntraModeCfg.html#ae0e684b32d3501867663070f6e1c22f2":[13,0,86,0],
-"structIntraModeCfg.html#aef6743e8fee9ca35c38da19091b9ee47":[13,0,86,4],
-"structIntraModeCfg.html#af939ab8fb5755b0f563c3d6537c5529e":[13,0,86,7],
+"structInterModeSearchStateNonrd.html":[13,0,82],
+"structInterModeSearchStateNonrd.html#a0cabdd6a7dfdee2da308b9e271d10bed":[13,0,82,7],
+"structInterModeSearchStateNonrd.html#a0d2e5f58a3f9254b8dc9b19ccc23f702":[13,0,82,6],
+"structInterModeSearchStateNonrd.html#a68ec2e02b4d7315a1ab243eeb2b0f100":[13,0,82,12],
+"structInterModeSearchStateNonrd.html#a7902e93c764b658c9fd23c734e06310a":[13,0,82,3],
+"structInterModeSearchStateNonrd.html#a7bf6b189051fc21d1512cd29f8c5d69f":[13,0,82,1],
+"structInterModeSearchStateNonrd.html#a87957fe5a1584caef2b7818e5da64695":[13,0,82,5],
+"structInterModeSearchStateNonrd.html#a9a6f2e0a44621f6ef8e564f48c7b8cc7":[13,0,82,11],
+"structInterModeSearchStateNonrd.html#aa3dd8ee97c07a4dc050cc3ef29cfd870":[13,0,82,8],
+"structInterModeSearchStateNonrd.html#ab9240c2a2cd6167b0d51e1b3bd2ffa77":[13,0,82,9],
+"structInterModeSearchStateNonrd.html#ac2af8e4822aec07824785cb557f065eb":[13,0,82,2],
+"structInterModeSearchStateNonrd.html#adc34c3bd6e76679bee3e4a4b07733e49":[13,0,82,10],
+"structInterModeSearchStateNonrd.html#adf419a54df62c1845b8319192ce31f3b":[13,0,82,0],
+"structInterModeSearchStateNonrd.html#afe7f91fe92c4dfdade435538380c9431":[13,0,82,4],
+"structInterpSearchFlags.html":[13,0,83],
+"structInterpSearchFlags.html#a1720ff86680c7e8e7b2f77d4a23d5790":[13,0,83,0],
+"structInterpSearchFlags.html#a92fde19334f66058b6eac0efa041cf34":[13,0,83,1],
+"structIntraBCMVCosts.html":[13,0,84],
+"structIntraBCMVCosts.html#a110357a01a87108133fccf1afefa389b":[13,0,84,2],
+"structIntraBCMVCosts.html#ad4a9b228c4d5a0d29244e540c034f126":[13,0,84,1],
+"structIntraBCMVCosts.html#ae77e28c15cf4f18cd35ea8406d9b1fd4":[13,0,84,0],
+"structIntraModeCfg.html":[13,0,85],
+"structIntraModeCfg.html#a09f1535b47b58079a6818ed31f636e92":[13,0,85,6],
+"structIntraModeCfg.html#a21efde3a70fba9fd93db0ea8229b15d6":[13,0,85,2],
+"structIntraModeCfg.html#a25e90d1483c243b3f1d68babc5006cc9":[13,0,85,8],
+"structIntraModeCfg.html#a5907afc4c7e63e9f64c2ab56600c3e77":[13,0,85,1],
+"structIntraModeCfg.html#a99fb2a4f0aafc9bd5ac17905e614f83c":[13,0,85,5],
+"structIntraModeCfg.html#aaf15940fb88791de54e8260a9d4b6e0a":[13,0,85,3],
+"structIntraModeCfg.html#ae0e684b32d3501867663070f6e1c22f2":[13,0,85,0],
+"structIntraModeCfg.html#aef6743e8fee9ca35c38da19091b9ee47":[13,0,85,4],
+"structIntraModeCfg.html#af939ab8fb5755b0f563c3d6537c5529e":[13,0,85,7],
 "structIntraModeSearchState.html":[12,2,2,1],
 "structIntraModeSearchState.html#a0472a732c8f9c98c8ea9b2acb37f5fd9":[12,2,2,1,0],
 "structIntraModeSearchState.html#a19c96626ab27bf6a702757073552502f":[12,2,2,1,3],
@@ -216,17 +222,17 @@ var NAVTREEINDEX6 =
 "structIntraModeSearchState.html#ad8f4c6456f23dde3054a96dec02f7ea9":[12,2,2,1,8],
 "structIntraModeSearchState.html#af2d8182817636c922c43c7322872e2a7":[12,2,2,1,5],
 "structIntraModeSearchState.html#af5816d3b8649ea51b3aa66f0cd9931a8":[12,2,2,1,10],
-"structKeyFrameCfg.html":[13,0,88],
-"structKeyFrameCfg.html#a0b8987c023f9e94b419195ebf81bc6a4":[13,0,88,1],
-"structKeyFrameCfg.html#a0d2de52e26a39ca0d06271272c94ab7a":[13,0,88,4],
-"structKeyFrameCfg.html#a4557b10d7f6d7cfb4df3c99876f97591":[13,0,88,5],
-"structKeyFrameCfg.html#a8c40a607b58692a1b0cac05d60422ec5":[13,0,88,9],
-"structKeyFrameCfg.html#a8d78931dc6f1292aea5a43f1a69d1b2d":[13,0,88,3],
-"structKeyFrameCfg.html#a917d99dd621257b6f2fc124ea9ca9381":[13,0,88,8],
-"structKeyFrameCfg.html#aaf3754dc88c530c69a547af1a12964c2":[13,0,88,2],
-"structKeyFrameCfg.html#ae5a2f1eb074f8cfb6a49c710f90cbb9b":[13,0,88,6],
-"structKeyFrameCfg.html#af2b0389436084c2a46d7c8b73c44d907":[13,0,88,0],
-"structKeyFrameCfg.html#af7bf324347fcf8476270fe208ddfc252":[13,0,88,7],
+"structKeyFrameCfg.html":[13,0,87],
+"structKeyFrameCfg.html#a0b8987c023f9e94b419195ebf81bc6a4":[13,0,87,1],
+"structKeyFrameCfg.html#a0d2de52e26a39ca0d06271272c94ab7a":[13,0,87,4],
+"structKeyFrameCfg.html#a4557b10d7f6d7cfb4df3c99876f97591":[13,0,87,5],
+"structKeyFrameCfg.html#a8c40a607b58692a1b0cac05d60422ec5":[13,0,87,9],
+"structKeyFrameCfg.html#a8d78931dc6f1292aea5a43f1a69d1b2d":[13,0,87,3],
+"structKeyFrameCfg.html#a917d99dd621257b6f2fc124ea9ca9381":[13,0,87,8],
+"structKeyFrameCfg.html#aaf3754dc88c530c69a547af1a12964c2":[13,0,87,2],
+"structKeyFrameCfg.html#ae5a2f1eb074f8cfb6a49c710f90cbb9b":[13,0,87,6],
+"structKeyFrameCfg.html#af2b0389436084c2a46d7c8b73c44d907":[13,0,87,0],
+"structKeyFrameCfg.html#af7bf324347fcf8476270fe208ddfc252":[13,0,87,7],
 "structLAYER__CONTEXT.html":[12,2,10,0],
 "structLAYER__CONTEXT.html#a1d897dac3039f8c548df285f6c59b9a9":[12,2,10,0,2],
 "structLAYER__CONTEXT.html#a4ff0c1a06b8fd96f5ff37bf2aa98b9d3":[12,2,10,0,0],
@@ -237,17 +243,11 @@ var NAVTREEINDEX6 =
 "structLAYER__CONTEXT.html#ab1a9c759d6a221c6acafcde147e08a7b":[12,2,10,0,7],
 "structLAYER__CONTEXT.html#ac84886e42f345445136e78d701fec643":[12,2,10,0,6],
 "structLAYER__CONTEXT.html#af1c6b09cc85e7314d989aae83a7b28d5":[12,2,10,0,1],
-"structLV__MAP__COEFF__COST.html":[13,0,90],
-"structLV__MAP__COEFF__COST.html#a21ff28247f7c01445252cf0d4d157726":[13,0,90,5],
-"structLV__MAP__COEFF__COST.html#a3b1604ef5cdf5ef6d5f80b1a2eff97c9":[13,0,90,0],
-"structLV__MAP__COEFF__COST.html#a524b66066193b2d558d701569a309cd2":[13,0,90,4],
-"structLV__MAP__COEFF__COST.html#ac13625e52afc8b9f56490d9b4e3763c8":[13,0,90,3],
-"structLV__MAP__COEFF__COST.html#ad30ba41c53bce80c8f4c06a966a71204":[13,0,90,1],
-"structLV__MAP__COEFF__COST.html#adbc5eac44e6077ce1a59d92736a0cb1f":[13,0,90,2],
-"structLV__MAP__EOB__COST.html":[13,0,91],
-"structLV__MAP__EOB__COST.html#a8e0e53ae7c9736000019c611ef5eb580":[13,0,91,0],
-"structMBMIExtFrameBufferInfo.html":[13,0,100],
-"structMBMIExtFrameBufferInfo.html#a4f34405dd12aa6f0fe1415c4f08b7823":[13,0,100,1],
-"structMBMIExtFrameBufferInfo.html#a774a8b281d7f026cbb5fd5889062d2c5":[13,0,100,2],
-"structMBMIExtFrameBufferInfo.html#aa3e1931e2edbe5ee3460688502a4dad6":[13,0,100,0]
+"structLV__MAP__COEFF__COST.html":[13,0,89],
+"structLV__MAP__COEFF__COST.html#a14f9d4c6db67fc6b8f05bc8dded96a67":[13,0,89,2],
+"structLV__MAP__COEFF__COST.html#a21ff28247f7c01445252cf0d4d157726":[13,0,89,5],
+"structLV__MAP__COEFF__COST.html#a3b1604ef5cdf5ef6d5f80b1a2eff97c9":[13,0,89,0],
+"structLV__MAP__COEFF__COST.html#a524b66066193b2d558d701569a309cd2":[13,0,89,4],
+"structLV__MAP__COEFF__COST.html#ac13625e52afc8b9f56490d9b4e3763c8":[13,0,89,3],
+"structLV__MAP__COEFF__COST.html#ad30ba41c53bce80c8f4c06a966a71204":[13,0,89,1]
 };
